Class: OodAppkit::Servers::Torque
- Inherits:
-
OodAppkit::Server
- Object
- OodAppkit::Server
- OodAppkit::Servers::Torque
- Defined in:
- lib/ood_appkit/servers/torque.rb
Overview
This defines a Torque server / client software installation
Instance Attribute Summary collapse
-
#prefix ⇒ Pathname
readonly
The path to the installation location for this software.
-
#version ⇒ String
readonly
The version of this software.
Attributes inherited from OodAppkit::Server
Instance Method Summary collapse
-
#bin ⇒ Pathname
The path to Torque software binaries.
-
#initialize(prefix:, version:, **kwargs) ⇒ Torque
constructor
A new instance of Torque.
-
#lib ⇒ Pathname
The path to Torque software library.
Constructor Details
#initialize(prefix:, version:, **kwargs) ⇒ Torque
Returns a new instance of Torque.
15 16 17 18 19 20 21 22 23 24 25 |
# File 'lib/ood_appkit/servers/torque.rb', line 15 def initialize(prefix:, version:, **kwargs) super(kwargs) # installation path @prefix = Pathname.new prefix raise ArgumentError, "prefix path doesn't exist (#{@prefix})" unless @prefix.exist? raise ArgumentError, "prefix not valid directory (#{@prefix})" unless @prefix.directory? # version number @version = version end |
Instance Attribute Details
#prefix ⇒ Pathname (readonly)
The path to the installation location for this software
7 8 9 |
# File 'lib/ood_appkit/servers/torque.rb', line 7 def prefix @prefix end |
#version ⇒ String (readonly)
The version of this software
11 12 13 |
# File 'lib/ood_appkit/servers/torque.rb', line 11 def version @version end |
Instance Method Details
#bin ⇒ Pathname
The path to Torque software binaries
39 40 41 |
# File 'lib/ood_appkit/servers/torque.rb', line 39 def bin prefix.join('bin') end |
#lib ⇒ Pathname
The path to Torque software library
31 32 33 |
# File 'lib/ood_appkit/servers/torque.rb', line 31 def lib prefix.join('lib') end |